%%
%% lettreLSV.cls 
%% N. Markey, D. Berwanger
%% 2005/11/01: first release
%%
%% 2005/12/02: ajout de \fromsigfile & co.
%% 2005/12/05: bugfixes
%%
%% 2009/12/04: nouveau logo + qqs nettoyages
%% 
%% 2017/11/20: removed border artwork, updated ENS logo
%% 
%% based on lettre.cls by Denis Megevand, Obs. de Geneve.
%% 
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{lettreLSV}[2009/12/04 v2.00]
%%
\newcommand\@ptsize{}
\def\@LSVafourpaper{a4paper}
\def\@LSVletterpaper{letterpaper}
\DeclareOption{10pt}{\renewcommand\@ptsize{0}}
\DeclareOption{11pt}{\renewcommand\@ptsize{1}}
\DeclareOption{12pt}{\renewcommand\@ptsize{2}}
\DeclareOption{twoside}{\@twosidetrue}
\DeclareOption{oneside}{\@twosidefalse}
\DeclareOption{leftborders}{\@leftborderstrue}
\DeclareOption{origdate}{\@origdatetrue\PackageWarningNoLine{lettre}{Mode `origdate'}}
\DeclareOption{draft}{\setlength\overfullrule{5pt}}
\DeclareOption{final}{\setlength\overfullrule{0pt}}
\DeclareOption{leqno}{\input{leqno.clo}}
\DeclareOption{fleqn}{\input{fleqn.clo}}
\DeclareOption{francais}{\def\defaultlanguage{francais}\def\babellang{french}}
\DeclareOption{deutsch}{\def\defaultlanguage{deutsch}\def\babellang{german}}
\DeclareOption{us}{\def\defaultlanguage{us}\def\babellang{english}}
\DeclareOption{english}{\def\defaultlanguage{english}\def\babellang{english}}
\DeclareOption{a4paper}{\edef\@LSVpapersize{\@LSVafourpaper}}
\DeclareOption{a4}{\edef\@LSVpapersize{\@LSVafourpaper}}
\DeclareOption{letterpaper}{\edef\@LSVpapersize{\@LSVletterpaper}}
\DeclareOption{letter}{\edef\@LSVpapersize{\@LSVletterpaper}}
\DeclareOption*{\IfFileExists{\CurrentOption.ins}
  {\xdef\@insfile{\CurrentOption.ins}}
  {\PackageWarningNoLine{lettre}{Option inconnue : `\CurrentOption'}}}
\newif\if@origdate\@origdatefalse
\newif\if@leftborders\@leftbordersfalse
\ExecuteOptions{11pt,oneside,final,francais}
\ProcessOptions
\input{size1\@ptsize.clo}
%%
%% .ins file is input at the end of this file (was done here previously)
%%
\def\uslanguage{us}
\@ifundefined{@LSVpapersize}
  {\ifx\defaultlanguage\uslanguage
    \edef\@LSVpapersize{\@LSVletterpaper}
   \else
    \edef\@LSVpapersize{\@LSVafourpaper}
   \fi}
  {}
\RequirePackage[\@LSVpapersize]{geometry}
\RequirePackage[\babellang]{babel}
\RequirePackage{graphicx}
\RequirePackage{textpos}
\RequirePackage{everypage}

%
%    ****************************************
%    *               POLICES                *
%    ****************************************
%
\DeclareOldFontCommand{\rm}{\rmfamily}{\mathrm}
\DeclareOldFontCommand{\sl}{\slshape}{\@nomath\sl}
\DeclareOldFontCommand{\it}{\itshape}{\mathit}
\DeclareOldFontCommand{\sc}{\scshape}{\@nomath\sc}
\DeclareOldFontCommand{\bf}{\bfseries}{\mathbf}
\DeclareOldFontCommand{\sf}{\sffamily}{\mathsf}
\DeclareOldFontCommand{\tt}{\ttfamily}{\mathtt}
\DeclareRobustCommand*{\cal}{\@fontswitch{\relax}{\mathcal}}
\DeclareRobustCommand*{\mit}{\@fontswitch{\relax}{\mathnormal}}
%
%    ****************************************
%    *       PARAGRAPHES : parametres       *
%    ****************************************
%
\lineskip  1pt%
\normallineskip 1pt%
\parskip  .7em%
\parindent 1.5em%
\topsep   .2em%
\partopsep 0pt%
\itemsep  .2em%
\renewcommand\baselinestretch{1}
%
\@lowpenalty   51\relax
\@medpenalty  151\relax
\@highpenalty 301\relax
\@beginparpenalty -\@lowpenalty 
\@endparpenalty   -\@lowpenalty
\@itempenalty     -\@lowpenalty
%
%    ****************************************
%    *      MISE-EN-PAGE : parametres       *
%    ****************************************
%
\ifx\@LSVpapersize\@LSVafourpaper
  \voffset          -1in%% suppression de l'offset vertical
  \topmargin        25mm%% marge sup.      25mm
  \headheight        0pt%
  \headsep           4mm%% sep. d'entete    4mm
  \textheight      250mm%% hauteur texte  250mm
  \footskip          9mm%% sep d'embase     9mm
%
% total vertical 25+4+250+9=288 mm, reste 9mm sur papier A4 (hauteur = 297mm)
%
\else
  \voffset          -1in%% suppression de l'offset vertical
  \topmargin        10mm%% marge sup.      15mm
  \headheight        0pt%
  \headsep           4mm%% sep. d'entete    4mm
  \textheight      250mm%% hauteur texte  250mm
  \footskip          9mm%% sep d'embase     9mm
\fi
%
% total vertical 10+4+250+9=273 mm, reste 6mm sur papier letter (hauteur = 279mm)
%
\footnotesep       5mm%
\marginparpush     1mm%
%
\hoffset          -1in%% suppression de l'offset horizontal
\oddsidemargin    35mm%% marge gauche    35mm
\evensidemargin   35mm%
\textwidth       150mm%% largeur texte  150mm
\marginparsep      4mm%% sep. note lat.  4mm
\marginparwidth   15mm%% larg. note lat 15mm
%
% total horizontal 25+160+4+15=204 mm, reste 6 mm sur A4 = 210 mm.
%
\skip\footins    4mm plus 2pt minus 4pt%
%
%    ************************************************
%    *       LE FORMAT LETTRE ET FAX DE             *
%    *        L'OBSERVATOIRE DE GENEVE              *
%    ************************************************
%
%    ************************************************
%    *   NEWCOUNTS, NEWDIMENS, NEWIFS, NEWWRITE     *
%    ************************************************
%
\newcount\auxcount
\newcount\c@infos\c@infos=1\relax
\newcount\c@labelstart
\newcount\c@lettre
\newcount\c@telefax
\newcount\emailcount
\newcount\faxpage
\newcount\sigflag
\newcount\signum
%
\newdimen\letterwidth
\newdimen\openingspace
\newdimen\openingindent
\newdimen\lettermargin
\newdimen\listmargin
\newdimen\sigspace
\newdimen\ssigindent
\newdimen\ssigwidth
\newdimen\msigwidth
\newdimen\fromaddress@let@width
\newdimen\fromlieu@let@width
\newdimen\toaddress@let@width
\newdimen\fromaddress@fax@width
\newdimen\faxstring@width
\newdimen\faxbox@width
\newdimen\toaddress@fax@width
\newdimen\fromname@fax@width
%
\newif\if@letter\@lettertrue
\newif\if@detail\@detailfalse 
%
\newwrite\@tensionaux
\newwrite\@dateaux
\newwrite\@etiqaux
\newwrite\@faxaux
%
%    ************************************************
%    *               MACROS INTERNES                *
%    ************************************************
%
\def\t#1#2{\begin{list}{#1}{\setlength{\labelsep}{10pt}%
                            \setlength{\labelwidth}{\listmargin}%
                            \setlength{\leftmargin}{\listmargin}%
                            \setlength{\listparindent}{0pt}}%
           \item #2%
           \end{list}}
\def\detailledaddress{\@detailtrue}%
%
\def\stopletter{\vskip0ptplus1filll}%
\def\stopfax{\vskip0ptplus1filll}%
%
\def\resetopenenv{%
        \faxpage=0\relax
        \csname\defaultlanguage\endcsname
        \def\concdecl{}%
        \def\fromlocation{}%
        }%
\def\resetcloseenv{
        \def\fromsig{}\def\fromssig{}\def\fromtsig{}
        \def\fromsigfile{}\def\fromssigfile{}\def\fromtsigfile{}
        \ps@plain
        \pagenumbering{arabic}       
        \onecolumn                   
        \signum=0\relax
        }
\def\resetauxenv{
        \def\auxflag{}
        \auxcount=0\relax
        \def\toref{}\def\fromref{}
        \def\telexnum{}\def\ccpnum{}
        }
\def\resetemailenv{
        \def\emailflag{}
        \emailcount=0\relax
        \def\@username{}
        \def\ccittnum{}\def\internetnum{}\def\bitnetnum{}\def\telepacnum{}\def\decnetnum{}
        }
%
% \@processto extrait \toname et \toaddress de l'environnement letter
%
\long\def\@processto#1{\@xproc #1\\@@@\ifx\toaddress\@empty 
    \else \@yproc #1@@@\fi}%
\long\def\@xproc #1\\#2@@@{\def\toname{#1}\def\toaddress{#2}}%
\long\def\@yproc #1\\#2@@@{\def\toaddress{#2}}%
%
\def\stopbreaks{\interlinepenalty \@M
   \def\par{\@@par\nobreak}\let\\=\@nobreakcr
   \let\vspace\@nobreakvspace}%
\def\@nobreakvspace{\@ifstar{\@nobreakvspacex}{\@nobreakvspacex}}%
\def\@nobreakvspacex#1{\ifvmode\nobreak\vskip #1\relax\else
               \@bsphack\vadjust{\nobreak\vskip #1}\@esphack\fi}%
\def\@nobreakcr{\vadjust{\penalty\@M}\@ifstar{\@xnewline}{\@xnewline}}%
\def\startbreaks{\let\\=\@normalcr
   \interlinepenalty 200\relax\def\par{\@@par\penalty -100\relax}}%
%
%*************************************************************
%                  MESSAGES ET AVERTISSSEMENTS               *
%*************************************************************
%
% Envoyes a la console et dans le fichier de log
%
% On peut supprimer allumer ou eteindre en tout temps les
% messages d'informations par les commandes \infos et \noinfos.
% Les avertissements ne peuvent etre supprimes.
%*************************************************************
\def\infos{\c@infos=1\relax}
\def\noinfos{\c@infos=0\relax}
\noinfos
%
\def\ltypeout#1{{\let\protect\string\immediate\write16{#1}}}%
\def\l@@warning#1{\typeout{LETTRE WARNING: #1.}}%
\def\l@warning#1{\l@@warning{#1\on@line}}%
\def\l@@info#1{\ifnum\c@infos=1\typeout{LETTRE INFO: #1.}\fi}%
%
%    ************************************************
%    *        ENVIRONNEMENTS LETTER ET FAX          *
%    ************************************************
%
\long\def\letter#1{%
  \global\advance\c@lettre\@ne
  \l@@info{Lettre \the\c@lettre}%
  \expandafter\ifx\csname newletter\the\c@lettre\endcsname\relax
     \expandafter\def\csname letter\the\c@lettre\endcsname{2}
  \else
     \expandafter\def\csname letter\the\c@lettre\endcsname{%
		\csname newletter\the\c@lettre\endcsname}
  \fi
  \ifodd\c@page%
  \else
    \if@twoside
      \l@@info{Saut de page force pour commencer la lettre sur une page impaire.}%
      \thispagestyle{empty}
      \hbox{}\penalty-10000\relax
    \fi
  \fi
  \c@page\@ne
  \resetopenenv\resetcloseenv\resetauxenv\resetemailenv
  \@lettertrue
  \@border
  \@pastille
  \@institut
  \if@leftborders
    \AddEverypageHook{%
      \ifnum\c@page=\@ne\else
       %% for some reason, these values are lost in the hook...
        \parskip=.7em
        \baselineskip=13.6pt
        \begin{textblock*}{\linewidth}(3.5cm,3.2cm)
 	  \@border
	\end{textblock*}
      \fi
    }
  \fi
  \let\opening=\letteropening
  \interlinepenalty=200\relax
  \@processto{#1}
}
\def\endletter{\par
  \ifdim\pagetotal < 50pt
    \immediate\write\@tensionaux{%
          \string\expandafter\string\def%
          \string\csname\space newletter\the\c@lettre\string\endcsname{-2}}%
    \l@@warning{Longueur de la derniere page : \the\pagetotal < 50pt}%
    \l@@warning{  tension de page modifiee a -2, veuillez recompiler}%
  \else
  \ifdim\pagetotal < 90pt
    \immediate\write\@tensionaux{%
          \string\expandafter\string\def%
          \string\csname\space newletter\the\c@lettre\string\endcsname{-4}}%
    \l@@warning{Longueur de la derniere page : \the\pagetotal < 90pt}%
    \l@@warning{  tension de page modifiee a -4, veuillez recompiler}%
  \else
  \ifdim\pagetotal < 130pt
    \immediate\write\@tensionaux{%
          \string\expandafter\string\def%
          \string\csname\space newletter\the\c@lettre\string\endcsname{-5}}%
    \l@@warning{Longueur de la derniere page : \the\pagetotal < 130pt}%
    \l@@warning{  tension de page modifiee a -5, veuillez recompiler}%
  \else
  \ifdim\pagetotal < 170pt
    \immediate\write\@tensionaux{%
          \string\expandafter\string\def%
          \string\csname\space newletter\the\c@lettre\string\endcsname{-6}}%
    \l@@warning{Longueur de la derniere page : \the\pagetotal < 170pt}%
    \l@@warning{  tension de page modifiee a -6, veuillez recompiler}%
  \else
  \ifdim\pagetotal < 210pt
    \immediate\write\@tensionaux{%
          \string\expandafter\string\def%
          \string\csname\space newletter\the\c@lettre\string\endcsname{4}}%
    \l@@warning{Longueur de la derniere page : \the\pagetotal < 210pt}%
    \l@@warning{  tension de page modifiee a 4, veuillez recompiler}%
  \else
  \ifdim\pagetotal < 250pt
    \immediate\write\@tensionaux{%
          \string\expandafter\string\def%
          \string\csname\space newletter\the\c@lettre\string\endcsname{6}}%
    \l@@warning{Longueur de la derniere page : \the\pagetotal < 250pt}%
    \l@@warning{  tension de page modifiee a 6, veuillez recompiler}%
  \else
    \immediate\write\@tensionaux{%
          \string\expandafter\string\def%
          \string\csname\space newletter\the\c@lettre\string\endcsname{%
          \csname letter\the\c@lettre\endcsname}}%
    \l@@info{Longueur de la derniere page : \the\pagetotal >= 250pt}%
  \fi
  \fi
  \fi
  \fi
  \fi
  \fi
  \stopletter
  \@@par\pagebreak\@@par
}
\long\def\telefax#1#2{%
  \global\advance\c@telefax\@ne
  \l@@info{Telefax \the\c@telefax}%
  \ifnum\c@telefax=\@ne
  \else
    \l@@warning{Un seul telefax par fichier, s.v.p.,}
    \l@@warning{  sinon le nombre de pages du fax est incorrect !}
  \fi
  \ifodd\c@page%
  \else
    \if@twoside
      \l@@info{Saut de page force pour commencer le telefax sur une page impaire.}%
      \thispagestyle{empty}
      \hbox{}\penalty-10000\relax
    \fi
  \fi
  \c@page\@ne
  \resetopenenv\resetcloseenv\resetauxenv\resetemailenv
  \@letterfalse
  \@border
  \@institut
  \def\tofaxnum{#1}%
  \let\opening=\faxopening
  \interlinepenalty=200\relax
  \makeatletter
  \@input{\jobname.fax}%
  \l@@info{Lecture du fichier auxiliaire de fax: Nombre total de pages=\totalpages}%
  \makeatother
  \@processto{#2}
}
\def\endtelefax{%
  \stopfax
  \begingroup 
    \advance\faxpage by\c@page
    \def\protect{\string}%
    \let\\=\relax
    \def\protect##1{\string##1\space}%
    \immediate\openout\@faxaux=\jobname.fax%
    \immediate\write\@faxaux{\string\def\string\totalpages{\the\faxpage}}%
    \if\totalpages\the\faxpage\else
      \l@@warning{Le nombre de pages du fax a change, }%
      \l@@warning{(ancien=\totalpages, nouveau=\the\faxpage) }%
      \l@@warning{  veuillez recompiler pour le corriger dans l'entete.}%
    \fi
  \endgroup
  \@@par\pagebreak\@@par
}%
%
%    ************************************************
%    *              OPENING ET CLOSING              *
%    ************************************************
%
\def\letteropening#1{%
                 \if@origdate
                   \expandafter\ifx\csname origdate\the\c@lettre
                                   \endcsname\relax
                   \else
                      \l@@info{Date originale lue dans \jobname.odt}%
                      \def\pdate{\csname origdate\the\c@lettre\endcsname}%
                   \fi
		   \l@@info{`\pdate' ecrit dans \jobname.odt}%
		   {\let\ier\relax
                   \fontencoding{OT1}\selectfont
		   \edef\ladate{\pdate}
		   \immediate\write\@dateaux{%
                     \string\expandafter\string\def%
                     \string\csname\space origdate\the\c@lettre
                     \string\endcsname{\ladate}}}%
                \fi
   \hbadness=10000\relax
   \thispagestyle{empty}% 
   \setlength{\unitlength}{1mm}%
   \advance\rightskip -75pt%
   \begin{picture}(\pict@let@width,\pict@let@height)%
                  (\pict@let@hoffset,\pict@let@voffset)%
     \put(\rule@hpos,\rule@vpos){\rule{\rule@length pt}{\rule@width pt}}%
     %\put(\rule@hpos,\rule@vpos){\line(1,0){\rule@length}}%
     \put(\fromaddress@let@hpos,\fromaddress@let@vpos){\makebox(0,0)[tl]{%
          \parbox[t]{\fromaddress@let@width}{%
	    \color{black}\sffamily\bfseries
                  \fromaddress\\[2mm]%
                  \ifx\@empty\fromlocation
                  \else \fromlocation \\%
                  \fi 
	    \fontsize{8pt}{9pt}\selectfont
                  \ifx\@empty\telephonenum
                  \else \tellabelname \telephonenum \\
                  \fi
                  \ifx\@empty\faxnum
                  \else \faxlabelname \faxnum \\
                  \fi
                  \ifx\@empty\emailnum
                  \else \mbox{\emaillabelname\href{mailto:\emailnum}{\url{\emailnum}}} \\
		    \ifx\@empty\secondemailnum
		    \else
		        \mbox{\phantom{\emaillabelname}\href{mailto:\secondemailnum}
			  {\url{\secondemailnum}}} \\
                  \fi\fi
                  \ifx\@empty\pageweb
                  \else \mbox{\pageweblabelname\href{\pageweb}{\url{\pageweb}}} \\
                  \fi}}}
     \put(\fromlieu@let@hpos,\fromlieu@let@vpos){\makebox(0,0)[bl]{%
          \parbox[t]{\fromlieu@let@width}{%
                 \ifx\@empty\fromlieu
                 \else\fromlieu, %
                 \fi 
                \ifx\@empty\pdate ~%
                \else\bgroup\fontencoding{OT1}\selectfont\pdate\egroup
                \fi}}}%
     \put(\toaddress@let@hpos,\toaddress@let@vpos){\makebox(0,0)[tl]{%
          \parbox{\toaddress@let@width}{%
                 \ifx\toname\@empty\else\toname\\\fi\toaddress}}}%
   \end{picture}%
   \par\vskip\csname letter\the\c@lettre\endcsname mm
   \advance\leftskip\lettermargin
   \advance\rightskip75pt%
   \ifx\@empty\auxflag
     \vspace{2\openingspace}%
   \else 
     \vspace{\openingspace}\auxline\vspace{\openingspace}%
   \fi
   \vskip\csname letter\the\c@lettre\endcsname mm
   \ifx\@empty\concdecl 
     \vspace{\openingspace}%
   \else 
     \concline\vspace{\openingspace}%
   \fi
   \vskip\csname letter\the\c@lettre\endcsname mm
   \hbadness=1000\relax
   {\parindent=\openingindent
   #1}\par\startbreaks\nobreak
   \let\flushleft=\letterflushleft
   \let\raggedright=\letterraggedright
   \let\center=\lettercenter
   \let\centering=\lettercentering
}%
%
\def\faxopening#1{%
   \hbadness=10000\relax
   \thispagestyle{empty}%
   \setlength{\unitlength}{1mm}%
   \advance\rightskip -75pt%
   \begin{picture}(\pict@fax@width,\pict@fax@height)
                   (\pict@fax@hoffset,\pict@fax@voffset)%
     \put(\fromaddress@fax@hpos,\fromaddress@fax@vpos){\makebox(0,0)[tl]{
          \parbox[t]{\fromaddress@fax@width}{\fromaddress}}}%
     \put(\faxstring@hpos,\faxstring@vpos){\makebox(0,0)[bl]{%
          \parbox[t]{\faxstring@width}{\telefaxstring}}}
   \end{picture}\par%
 \par\vspace{5mm}%
  \makebox[\faxbox@width]{\scriptsize\telephonelabelname\telephonenum
   \hfill\telefaxlabelname\faxnum
   \ifx\@empty\emailnum\else\hfill\emaillabelname{\url{\emailnum}}
     \ifx\@empty\secondemailnum\else\hfill\emaillabelname{\url{\secondemailnum}}\fi
   \fi
   \ifx\@empty\telexnum\else\hfill\telexlabelname\telexnum\fi}%
 \par
 \begin{tabular*}{\faxbox@width}[t]{l@{\hspace{5mm}}p{70mm}@{\hfill}r}%
    \hline
    \multicolumn{3}{@{}c@{}}{\vrule height 0pt depth 0pt width \faxbox@width}\\
    \headtoname
       &\parbox[t]{\toaddress@fax@width}{\toname\\\toaddress}%
       &\telefaxname\tofaxnum\\%
    \\%
    \headfromname
       &\parbox[t]{\fromname@fax@width}{\ifx\@empty\fromlocation
                                       \fromname
                                   \else
                                       \fromlocation
                                   \fi}%
       &\pagetotalname\totalpages\\%
 \end{tabular*}\par%
 \begin{tabular*}{\faxbox@width}[t]{@{\hfill}c@{\hfill}}%
    \hline
    \vrule height 3ex depth 7pt width 0pt\faxwarning\\%
    \hline
 \end{tabular*}\par%
 \begin{tabular*}{\faxbox@width}[t]{@{}r@{}}%
    \vrule height 0pt depth 0pt width \faxbox@width\\
    \multicolumn{1}{r}{\ifx\@empty\fromlieu
                       \else\fromlieu, %
                       \fi
                 \if@origdate
                   \expandafter\ifx\csname origdate\the\c@lettre
                                   \endcsname\relax
                   \else
                      \l@@info{Date originale lue dans \jobname.odt}%
                      \def\pdate{\csname origdate\the\c@lettre\endcsname}%
                   \fi
                   \l@@info{`\pdate' ecrit dans \jobname.odt}%
                   \immediate\write\@dateaux{%
                        \string\expandafter\string\def%
                        \string\csname\space origdate\the\c@lettre
                        \string\endcsname{\pdate}}%
                \fi
                \ifx\@empty\pdate ~%
                \else \pdate
                \fi}\\%
 \end{tabular*}%
 \par
   \vspace{\openingspace}%
   \advance\leftskip  \lettermargin
   \advance\rightskip 75pt%
   \ifx\@empty\concdecl 
     \vspace{\openingspace}%
   \else 
     \concline\vspace{\openingspace}%
   \fi
   \hbadness=1000\relax
   {\parindent=\openingindent
   #1}\par\startbreaks\nobreak
   \let\flushleft=\letterflushleft
   \let\raggedright=\letterraggedright
   \let\center=\lettercenter
   \let\centering=\lettercentering}%
%
\long\def\closing#1{%
  \def\@arg{#1}
  \ifx\@arg\@empty\let\@argspace\@arg\else\def\@argspace{#1\vspace*{10mm}}\fi
  \let\center=\normalcenter
  \let\centering=\normalcentering
  \let\flushleft=\normalflushleft
  \let\raggedright=\normalraggedright
  \par\stopbreaks
  \if@letter
    \vskip\csname letter\the\c@lettre\endcsname mm
  \fi
  \par\vspace{2\parskip}%
  \nobreak
  \noindent
  \l@@info{Signature \ifcase\signum manquante \or simple\or double\or triple\fi}%
  \ifcase\sigflag
    \parbox[t]{\letterwidth}{\@argspace}%
    \par\vspace*{\parskip}%
        \vspace*{\sigspace}%
    \if@letter
      \vskip\csname letter\the\c@lettre\endcsname mm
      \vskip\csname letter\the\c@lettre\endcsname mm
    \fi
    \ifcase\signum
       \hspace*{\ssigindent}%
       \noindent
       \parbox[t]{\ssigwidth}{\centering \ignorespaces\fromname}%
    \or
       \vspace*{\parskip}%
       \hspace*{\ssigindent}%
       \noindent
       \parbox[t]{\ssigwidth}{\centering 
	   \ifx\fromsigfile\@empty
	     \vspace*{\sigspace}
	   \else
	     \ifx\fromsigoarg\@empty
	       \includegraphics[width=4cm]{\fromsigfile}%
	     \else
	       \expandafter\includegraphics\expandafter[\fromsigoarg]{\fromsigfile}%
             \fi
           \fi
	   \par\fromsig}
    \or
       \vspace*{\parskip}%
       \msigwidth=\letterwidth
       \divide\msigwidth by 2\relax
       \advance\msigwidth -3pt%
       \noindent
       \mbox{\parbox[t]{\msigwidth}{\centering
	   \ifx\fromsigfile\@empty
	     \vspace*{\sigspace}
	   \else
	   \ifx\fromsigoarg\@empty
	     \includegraphics[width=4cm]{\fromsigfile}%
	   \else
	     \expandafter\includegraphics\expandafter[\fromsigoarg]{\fromsigfile}%
           \fi\fi	   
	   \par\fromsig }%
             \parbox[t]{\msigwidth}{\centering
	   \ifx\fromssigfile\@empty
	     \vspace*{\sigspace}
	   \else
	   \ifx\fromssigoarg\@empty
	     \includegraphics[width=4cm]{\fromssigfile}%
	   \else
	     \expandafter\includegraphics\expandafter[\fromssigoarg]{\fromssigfile}%
           \fi\fi	   
	   \par\fromssig}}%
    \or
       \vspace*{\parskip}%
       \msigwidth=\letterwidth
       \divide\msigwidth by 3\relax
       \advance\msigwidth -3pt%
       \noindent
       \mbox{\parbox[t]{\msigwidth}{\centering
	   \ifx\fromsigfile\@empty
	     \vspace*{\sigspace}
	   \else
	   \ifx\fromsigoarg\@empty
	     \includegraphics[width=4cm]{\fromsigfile}%
	   \else
	     \expandafter\includegraphics\expandafter[\fromsigoarg]{\fromsigfile}%
           \fi\fi
	   \par\fromsig }%
             \parbox[t]{\msigwidth}{\centering
	   \ifx\fromssigfile\@empty
	     \vspace*{\sigspace}
	   \else
	   \ifx\fromssigoarg\@empty
	     \includegraphics[width=4cm]{\fromssigfile}%
	   \else
	     \expandafter\includegraphics\expandafter[\fromssigoarg]{\fromssigfile}%
           \fi\fi
	   \par\fromssig}%
             \parbox[t]{\msigwidth}{\centering
	   \ifx\fromtsigfile\@empty
	     \vspace*{\sigspace}
	   \else
	   \ifx\fromtsigoarg\@empty
	     \includegraphics[width=4cm]{\fromtsigfile}%
	   \else
	     \expandafter\includegraphics\expandafter[\fromtsigoarg]{\fromtsigfile}%
           \fi\fi
       	   \par\fromtsig}}%
    \fi
  \or
    \ifcase\signum
        \hspace*{\ssigindent}%
        \parbox[t]{\ssigwidth}%
        {\centering \ignorespaces
        \@argspace%
        \par\vspace*{2\parskip}%
            \vspace*{\sigspace}%
        \fromname}%
    \or
        \hspace*{\ssigindent}%
        \parbox[t]{\ssigwidth}%
        {\centering \ignorespaces
        \@argspace%
        \par\vspace*{4\parskip}%
            \vspace*{\sigspace}%
	   \ifx\fromsigfile\@empty
	     \vspace*{\sigspace}
	   \else
	   \ifx\fromsigoarg\@empty
	     \includegraphics[width=4cm]{\fromsigfile}%
	   \else
	     \expandafter\includegraphics\expandafter[\fromsigoarg]{\fromsigfile}%
           \fi
	   \fi
	   \par\fromsig}%
    \or
       \parbox[t]{\letterwidth}{\@argspace}%
       \par\vspace*{2\parskip}%
           \vspace*{\sigspace}%
       \msigwidth=\letterwidth
       \divide\msigwidth by 2\relax
       \advance\msigwidth -3pt%
       \noindent
       \mbox{\parbox[t]{\msigwidth}{\centering
	   \ifx\fromsigfile\@empty
	     \vspace*{\sigspace}
	   \else
	   \ifx\fromsigoarg\@empty
	     \includegraphics[width=4cm]{\fromsigfile}%
	   \else
	     \expandafter\includegraphics\expandafter[\fromsigoarg]{\fromsigfile}%
           \fi
	   \fi
	   \par\fromsig}%
             \parbox[t]{\msigwidth}{\centering
	   \ifx\fromssigfile\@empty
	     \vspace*{\sigspace}
	   \else
	   \ifx\fromssigoarg\@empty
	     \includegraphics[width=4cm]{\fromssigfile}%
	   \else
	     \expandafter\includegraphics\expandafter[\fromssigoarg]{\fromssigfile}%
           \fi
	   \fi
       	   \par\fromssig}}%
    \or
       \parbox[t]{\letterwidth}{\@argspace}%
       \par\vspace*{2\parskip}%
           \vspace*{\sigspace}%
       \msigwidth=\letterwidth
       \divide\msigwidth by 3\relax
       \advance\msigwidth -3pt%
       \noindent
       \mbox{\parbox[t]{\msigwidth}{\centering
	   \ifx\fromsigfile\@empty
	     \vspace*{\sigspace}
	   \else
	   \ifx\fromsigoarg\@empty
	     \includegraphics[width=4cm]{\fromsigfile}%
	   \else
	     \expandafter\includegraphics\expandafter[\fromsigoarg]{\fromsigfile}%
           \fi
	   \fi
	   \par\fromsig}%
             \parbox[t]{\msigwidth}{\centering
	   \ifx\fromssigfile\@empty
	     \vspace*{\sigspace}
	   \else
	   \ifx\fromssigoarg\@empty
	     \includegraphics[width=4cm]{\fromssigfile}%
	   \else
	     \expandafter\includegraphics\expandafter[\fromssigoarg]{\fromssigfile}%
           \fi
	   \fi
	   \par\fromssig}%
             \parbox[t]{\msigwidth}{\centering
	   \ifx\fromtsigfile\@empty
	     \vspace*{\sigspace}
	   \else
	   \ifx\fromtsigoarg\@empty
	     \includegraphics[width=4cm]{\fromtsigfile}%
	   \else
	     \expandafter\includegraphics\expandafter[\fromtsigoarg]{\fromtsigfile}%
           \fi
	   \fi
	   \par\fromtsig}}%
    \fi
  \fi
  \par\vfill\startbreaks
}%
%
%    ************************************************
%    *           COMMANDES UTILISATEURS             *
%    ************************************************
%
\def\defifnotyet#1#2{\expandafter\csname #1\endcsname\relax
  \expandafter\def\csname #1\endcsname{#2}}

\def\marge#1{%
 \lettermargin=#1%
 \listmargin=#1%
 \leftmargini=\listmargin%
   \advance\leftmargini   0.5em%
 \letterwidth=\textwidth
   \advance\letterwidth by -\lettermargin
   \advance\letterwidth by 0pt}%
%
\def\basdepage#1{%
  \def\bdp{#1}}%
%
\def\tension#1{%
  \if@letter
    \expandafter\def\csname letter\the\c@lettre\endcsname{#1}%
  \fi
}%
%
\def\addpages#1{%
  \l@@info{Pages additionnelles: #1}%
  \advance\faxpage by #1}%
%
\def\name#1{\def\fromname{#1}}%
%
\def\signature{\@ifnextchar[{\@signature}{\@signature[]}}
\def\@signature[#1]#2{%
  \@@signature[#1,]{#2}
}
\def\@@signature[#1,#2]#3{%
  \ifnum\signum=0\relax
    \def\fromsig{#3}\signum=1\relax
    \def\fromsigfile{#1}%
    \def\fromsigoarg{#2}%
  \else
    \l@@warning{Signature deja definie}%
  \fi
}%
\def\secondsignature{\@ifnextchar[{\@secondsignature}{\@secondsignature[]}}
\def\@secondsignature[#1]#2{%
  \@@secondsignature[#1,]{#2}
}
\def\@@secondsignature[#1,#2]#3{%
  \ifnum\signum=1\relax
    \def\fromssig{#3}\signum=2\relax
    \def\fromssigfile{#1}%
    \def\fromssigoarg{#2}%
  \else
    \l@@warning{Seconde signature illegale ou deja definie}%
  \fi
}%
\def\thirdsignature{\@ifnextchar[{\@thirdsignature}{\@thirdsignature[]}}
\def\@thirdsignature[#1]#2{%
  \@@thirdsignature[#1,]{#2}
}
\def\@@thirdsignature[#1,#2]#3{%
  \ifnum\signum=2\relax
    \def\fromtsig{#3}\signum=3\relax
    \def\fromtsigfile{#1}%
    \def\fromtsigoarg{#2}%
  \else
    \l@@warning{Troisieme signature illegale ou deja definie}%
  \fi
}%
%
\def\vref#1{\l@@warning{La commande \string\Vref\ devrait etre utilisee.}
            \def\auxflag{.}%
            \def\toref{\parbox[t]{17mm}{#1}}}%
\def\Vref#1{\def\auxflag{.}%
            \def\toref{\parbox[t]{17mm}{#1}}}%
\def\nref#1{\l@@warning{La commande \string\Nref~ devrait etre utilisee.}
            \def\auxflag{.}%
            \def\fromref{\parbox[t]{17mm}{#1}}}%
\def\Nref#1{\def\auxflag{.}%
            \def\fromref{\parbox[t]{17mm}{#1}}}%
%
\def\concline{%
         \noindent\parbox[t]{\letterwidth}%
           {\textbf{\concdecl\strut}}%
%           {\@hangfrom{\textrm{\concname}}\ignorespaces\concdecl\strut}%
         \par}%
%
\def\auxline{%
  \l@@info{Ligne auxiliaire demandee}%
  {\scriptsize
   \vrefname%
    \ifx\@empty \toref
      \hspace{21mm}\hfill%
    \else 
      {\small\toref}\hfill%
    \fi
   \nrefname%
    \ifx\@empty \fromref
      \hspace{21mm}\hfill%
    \else 
      {\small\fromref}\hfill
    \fi
    \ifx\@empty \telexnum
      \hfill%
    \else 
      T\'ELEX\ \telexnum\hspace{5mm}%
    \fi
    \ifx\@empty \ccpnum
      \hfill%
    \else 
      C.C.P.\ \ccpnum\hspace{5mm}%
    \fi}\par}%
%
\def\emailine{%
  \l@@info{Ligne d'E-Mail demandee}%
  {\scriptsize
    \emaillabelname\hfill\ttfamily
    \ifx\@empty \ccittnum
    \else
     \hfill \ccittnum\hfill
    \fi
    \ifx\@empty \internetnum
    \else
     \hfill \internetnum\hfill
    \fi
    \ifx\@empty \bitnetnum
    \else
     \hfill \bitnetnum\hfill
    \fi
    \ifx\@empty \telepacnum
    \else 
     \hfill \telepacnum\hfill
    \fi
    \ifx\@empty \decnetnum
    \else 
     \hfill \decnetnum\hfill
    \fi
    \ifnum\emailcount<3\relax
     \hfill\mbox{}%
    \fi}}%
%
\long\def\address#1{\l@@info{Adresse precisee}\def\fromaddress{#1}}%
%\long\def\address*#1{\if@letter
%                        \l@@info{Adresse avec nom precisee}%
%                        \def\fromaddress{\fromname\\#1}
%                     \else
%                        \l@@warning{Commande illegale dans un fax}
%                     \fi}%
%
\def\nodate{\l@@info{Date supprimee}\def\pdate{}}%
\def\date#1{\l@@info{Date precisee}\def\pdate{#1}}%
%
\def\nolieu{\l@@info{Lieu supprime}\def\fromlieu{}}%
\def\lieu#1{\l@@info{Lieu precise}\def\fromlieu{#1}}%
%
\def\conc#1{\l@@info{Champ d'objet defini}\def\concdecl{#1}}%
%
\def\location#1{\l@@info{Precision d'adresse definie}\def\fromlocation{#1}}%
%
\def\notelephone{\l@@info{Numero de telephone supprime}\def\telephonenum{}}%
\def\telephone#1{\l@@info{Numero de telephone precise}\def\telephonenum{#1}}%
%
\def\nofax{\l@@info{Numero de fax supprime}\def\faxnum{}}%
\def\fax#1{\l@@info{Numero de fax precise}\def\faxnum{#1}}%
%
\def\email#1{\l@@info{Numero d'E-Mail precise}\def\emailnum{#1}}%
\def\secondemail#1{\l@@info{Numero d'E-Mail precise}\def\secondemailnum{#1}}%
\def\noemail{\def\emailnum{}\def\secondemailnum{}}
\def\web#1{\l@@info{Adresse web precise}\def\pageweb{#1}}%
\def\noweb{\def\pageweb{}}
%
\def\smail#1{\l@@info{Snail Mail precise}\def\snailmail{#1}}%
\def\nosmail{\l@@info{No Snail Mail}\let\snailmail\relax}%
%
\def\username#1{\def\@username{#1}}%
%
\def\ccitt#1{\ifnum\emailcount<3\relax
                  \def\emailflag{.}%
                  \advance\emailcount by 1\relax
                   \def\ccittnum{\ifx\@empty \@username
                                           \l@@warning{<<username>> indefini}
                                           #1%
                                  \else
                                        S=\@username;#1%
                               \fi}%
                \else
                  \def\ccittnum{}%
                \fi}%
\def\internet#1{\ifnum\emailcount<3\relax
                  \def\emailflag{.}%
                  \advance\emailcount by 1\relax
                   \def\internetnum{\ifx\@empty \@username
                                           \l@@warning{<<username>> indefini}
                                           #1\relax
                                    \else
                                        \@username @#1\relax
                                 \fi}%
                \else
                  \def\internetnum{}%
                \fi}%
\def\bitnet#1{\ifnum\emailcount<3\relax
               \def\emailflag{.}%
               \advance\emailcount by 1\relax
               \def\bitnetnum{\ifx\@empty \@username
                                     \l@@warning{<<username>> indefini}
                                     #1\relax
                                   \else
                                  \@username\ at #1\relax
                                \fi}%
             \else
               \def\bitnetnum{}%
             \fi}%
\def\telepac#1{\ifnum\emailcount<3\relax
             \def\emailflag{.}%
             \advance\emailcount by 1\relax
              \def\telepacnum{\ifx\@empty \@username
                                 \l@@warning{<<username>> indefini}
                                 #1\relax
                              \else
                              #1::\@username
                           \fi}%
           \else
             \def\telepacnum{}%
           \fi}%
\def\decnet#1{\ifnum\emailcount<3\relax
             \def\emailflag{.}%
             \advance\emailcount by 1\relax
              \def\decnetnum{\ifx\@empty \@username
                                \l@@warning{<<username>> indefini}
                                #1\relax
                              \else
                             #1::\@username
                           \fi}%
           \else
             \def\decnetnum{}%
           \fi}%
\def\telex#1{\ifnum\auxcount<2\relax
               \def\auxflag{.}%
               \advance\auxcount by 1\relax
               \def\telexnum{#1}%
             \else
               \def\telexnum{}%
             \fi}%
\def\ccp#1{\ifnum\auxcount<2\relax
             \def\auxflag{.}%
             \advance\auxcount by 1\relax
             \def\ccpnum{#1}%
           \else
             \def\ccpnum{}%
           \fi}%
%
\def\ps#1#2{\penalty100\relax
  \if@letter
    \vskip\csname letter\the\c@lettre\endcsname mm
  \fi
  \l@@info{Post-scriptum defini}%
  \noindent{#1}{#2\\}\vfill\penalty-100\relax}%
%
\def\cc#1{\penalty100\relax
  \if@letter
    \vskip\csname letter\the\c@lettre\endcsname mm
  \fi
  \l@@info{Copies declarees}%
  \noindent{\ccname}{#1\\}\vfill\penalty-100\relax}%
%
\def\encl#1{\penalty100\relax
  \if@letter
    \vskip\csname letter\the\c@lettre\endcsname mm
  \fi
  \l@@info{Annexes declarees}%
  \noindent{\enclname}{#1\\}\vfill\penalty-100\relax}%
\def\mencl{\penalty100\relax
  \if@letter
    \vskip\csname letter\the\c@lettre\endcsname mm
  \fi
  \l@@info{Annexes mentionnees}%
  \noindent{\mentionname\\}{~}\vfill\penalty-100\relax}%
%
%    ****************************************
%    *   DEFINITIONS DEPENDANT DU LANGAGE   *
%    ****************************************
%
\def\FAXSTR{\fontfamily{cmdh}\fontseries{m}\fontshape{n}\selectfont}%
\def\langfrancais{%
  \def\FRANCAIS{francais}
  \ifx\defaultlanguage\FRANCAIS\else\l@@info{Langage modifie: francais}\fi%
  \ifx\undefined\extrasfrancais\else % style babel and French language loaded
    \selectlanguage{francais}
    \reset@frenchitemize
  \fi
  \sigflag=0\relax
  \def\cejour{le
    \ifx\ier\undefined\def\ier{er}\fi
    \ifnum\day=1\relax 1\ier{}\else \number\day\fi
    \space\ifcase\month\or
    janvier\or f\'evrier\or mars\or avril\or mai\or juin\or
    juillet\or ao\^ut\or septembre\or octobre\or novembre\or d\'ecembre\fi
    \space \number\year}%
  \def\faxwarning{\large\slshape\bfseries En cas de mauvaise transmission, 
                               appelez s.v.p. l'op\'erateur t\'el\'efax}%
  \def\telefaxstring{{\FAXSTR T~\'E~L~\'E~F~A~X}}%
  \def\telephonelabelname{T\'EL\'EPHONE :~}%
  \def\telefaxlabelname{T\'EL\'EFAX :~}%
  \def\telefaxname{T\'el\'ecopie :~}%
  \def\tellabelname{T\'el.:~}%
  \def\faxlabelname{Fax :~}%
  \def\emaillabelname{E-mail :~}%
  \def\pageweblabelname{URL :~}%
  \def\telexlabelname{T\'ELEX :~}%
  \def\headtoname{\`A :~}%
  \def\headfromname{De :~}%
  \def\pagetotalname{Nombre de pages :~}%
  \def\concname{Objet :~}%
  \def\ccname{C.c.~}%
%  \def\enclname{P.j.~}%
  \def\enclname{}%
  \def\mentionname{Annexe(s) mentionn\'ee(s)}%
  \def\vrefname{V.\raise.4ex\hbox{\tiny /}r\'ef.~}
  \def\nrefname{N.\raise.4ex\hbox{\tiny /}r\'ef.~}
}%
\def\langenglish{%
  \def\ENGLISH{english}
  \ifx\defaultlanguage\ENGLISH\else\l@@info{Langage modifie: anglais}\fi%
  \selectlanguage{english}
  \sigflag=1\relax
  \def\cejour{\ifcase\month\or
    January\or February\or March\or April\or May\or June\or
    July\or August\or September\or October\or November\or December\fi
    \space\number\day ,\space\number\year}%
  \def\faxwarning{\large\slshape\bfseries If improperly transmitted, please 
                               call the telefax operator}%
  \def\telefaxstring{{\FAXSTR T~E~L~E~F~A~X}}%
  \def\telephonelabelname{TELEPHONE:~}%
  \def\telefaxlabelname{TELEFAX:~}%
  \def\telefaxname{Telefax:~}%
  \def\tellabelname{Tel:~}%
  \def\faxlabelname{Fax:~}%
  \def\emaillabelname{Mail:~}%
  \def\pageweblabelname{URL:~}%
  \def\telexlabelname{TELEX:~}%
  \def\headtoname{To:~}%
  \def\headfromname{From:~}%
  \def\pagetotalname{Total pages:~}%
  \def\concname{Re:~}%
  \def\ccname{Cc:~}%
  \def\enclname{Encl(s):~}%
  \def\mentionname{Encl(s).}%
  \def\vrefname{Y.\raise.4ex\hbox{\tiny /}ref.~}
  \def\nrefname{O.\raise.4ex\hbox{\tiny /}ref.~}
}%
\def\langus{%
  \def\US{us}
  \ifx\defaultlanguage\US\else\l@@info{Langage modifie: americain}\fi%
  \selectlanguage{english}
  \sigflag=1\relax
  \def\cejour{\ifcase\month\or
    January\or February\or March\or April\or May\or June\or
    July\or August\or September\or October\or November\or December\fi
    \space\number\day ,\space\number\year}%
  \def\faxwarning{\large\slshape\bfseries If improperly transmitted, please 
                               call the telefax operator}%
  \def\telefaxstring{{\FAXSTR T~E~L~E~F~A~X}}%
  \def\telephonelabelname{PHONE:~}%
  \def\telefaxlabelname{TELEFAX:~}%
  \def\telefaxname{Telefax:~}%
  \def\tellabelname{Phn:~}%
  \def\faxlabelname{Fax:~}%
  \def\emaillabelname{E-mail:~}%
  \def\pageweblabelname{URL :~}%
  \def\telexlabelname{TELEX:~}%
  \def\headtoname{To:~}%
  \def\headfromname{From:~}%
  \def\pagetotalname{Total pages:~}%
  \def\concname{Re:~}%
  \def\ccname{Cc:~}%
  \def\enclname{Encl(s):~}%
  \def\mentionname{Encl(s).}%
  \def\vrefname{Y.\raise.4ex\hbox{\tiny /}ref.~}
  \def\nrefname{O.\raise.4ex\hbox{\tiny /}ref.~}
}%
\def\langdeutsch{%
  \def\DEUTSCH{deutsch}
  \ifx\defaultlanguage\DEUTSCH\else\l@@info{Langage modifie: allemand}\fi%
  \selectlanguage{german}
  \sigflag=1\relax
  \def\cejour{den \number\day .\space\ifcase\month\or
  Januar\or Februar\or M\"arz\or April\or Mai\or Juni\or
  Juli\or August\or September\or Oktober\or November\or Dezember\fi
  \space \number\year}%
  \def\concname{Betrifft: }%
  \def\faxwarning{\large\slshape\bfseries Bitte unrichtige \"Ubertragungen dem 
                               Sender telefonisch melden}%
  \def\telefaxstring{{\FAXSTR T~E~L~E~F~A~X}}%
  \def\telephonelabelname{TELEFON:~}%
  \def\telefaxlabelname{TELEFAX:~}%
  \def\telefaxname{Telefax:~}%
  \def\tellabelname{Tel:~}%
  \def\faxlabelname{Fax:~}%
  \def\emaillabelname{E-Mail:~}%
  \def\pageweblabelname{URL :~}%
  \def\telexlabelname{TELEX:~}%
  \def\headtoname{An:~}%
  \def\headfromname{Von:~}%
  \def\pagetotalname{Gesamtanzahl der Bl\"atter:~}%
  \def\concname{Betrifft:~}%
  \def\ccname{Kopie an:~}%
  \def\enclname{Beilage(n):~}%
  \def\mentionname{Beilage(n) erw\"ahnt}%
  \def\vrefname{Ihr Zeichen~}
  \def\nrefname{Unser Zeichen~}
}%
%
%************************************************************************
%
% \document redefini pour ecrire '\startlabels' sur le fichier .etq 
% et executer \@startlabels.
%
%************************************************************************
%
\AtBeginDocument{%
  \makeatletter
  \@input{\jobname.tns}%
  \@input{\jobname.odt}%
  \begingroup\@floatplacement\@dblfloatplacement
  \immediate\openout\@tensionaux=\jobname.tns%
  \if@origdate
    \immediate\openout\@dateaux=\jobname.odt%
  \fi
  \endgroup
  \makeatother
  \csname lang\defaultlanguage\endcsname
}
%
%************************************************************************
%
% \enddocument redefini pour sortir la page d'etiquettes, si necessaire.
%
%************************************************************************
%
\AtEndDocument{%
  \l@@info{Nombre de lettres :\the\c@lettre}%
  \l@@info{Nombre de telefax :\the\c@telefax}%
  \newpage\begingroup 
  \immediate\closeout\@tensionaux%
  \if@origdate
    \immediate\closeout\@dateaux%
  \fi
  \if@letter
  \else
    \immediate\closeout\@faxaux%
  \fi
  \endgroup
}%
%
%    ****************************************
%    *             STYLES DE PAGE           *
%    ****************************************
%
%
\def\@texttop{\ifnum\c@page=1\vskip 0pt plus .00001fil\relax\fi}%
%
\if@twoside
  \def\ps@headings{%
    \headheight 12pt%
    \headsep 25pt%
    \def\@oddhead{{\hspace{15mm}\ifx\@empty\fromlieu\else\fromlieu , \fi
                                  \pdate\hfill Page \thepage}}%
    \def\@oddfoot{}%
    \def\@evenhead{{Page \thepage\hfill\ifx\@empty\fromlieu\else\fromlieu , \fi
                                  \pdate\hspace{15mm}}}%
    \def\@evenfoot{}}%
\else
  \def\ps@headings{%
    \headheight 12pt%
    \headsep 25pt%
    \def\@oddhead{{\hspace{15mm}\ifx\@empty\fromlieu\else\fromlieu , \fi
                                  \pdate\hfill Page \thepage}}%
    \def\@oddfoot{}%
    \def\@evenhead{}%
    \def\@evenfoot{}}%
\fi
%
\def\ps@empty{%
   \headheight 0pt%
   \headsep 9pt%
   \def\@oddhead{}%
   \def\@oddfoot{%
       \ifnum\c@page=1\relax
          \ifx\@empty\emailflag
             \ifx\@empty\bdp
             \else
                \hbadness=10000\relax
                \rlap{\parbox{\textwidth}{\vskip21pt\rule{\textwidth}{.4pt}\\\bdp}}
                \hfill\null
                \hbadness=1000\relax
             \fi
          \else
             \hbadness=10000\relax
             \rlap{\parbox{\textwidth}{\mbox{}\\\rule{\textwidth}{.4pt}\\\emailine}}%
             \hfill\null
             \hbadness=1000\relax
          \fi
       \fi}%
   \def\@evenhead{}%
   \def\@evenfoot{}}%
%
\def\ps@firstpage{%
   \headheight 12pt%
   \headsep 25pt%
   \def\@oddhead{}%
   \def\@oddfoot{}%
   \def\@evenhead{}%
   \def\@evenfoot{}}%
%
\def\ps@plain{%
   \headheight 0pt%
   \headsep 9pt%
   \def\@oddhead{}%
   \def\@oddfoot{\textrm{\hfill\thepage\hfill}}%
   \def\@evenhead{}%
   \def\@evenfoot{\textrm{\hfill\thepage\hfill}}}%
%
%    ****************************************
%    *        CENTER et FLUSHLEFT           *
%    ****************************************
%
\def\normalcenter{\trivlist \normalcentering\item[]}%
\def\lettercenter{\trivlist \lettercentering\item[]}%
\def\normalcentering{\let\\=\@centercr\rightskip\@flushglue
                     \leftskip\@flushglue
                     \parindent\z@\parfillskip\z@}%
\def\lettercentering{\let\\=\@centercr\rightskip\@flushglue
                     \leftskip\@flushglue\advance\leftskip\lettermargin
                     \parindent\z@\parfillskip\z@}%
\let\endcenter=\endtrivlist
%
\def\normalflushleft{\trivlist \normalraggedright\item[]}%
\def\letterflushleft{\trivlist \letterraggedright\item[]}%
\def\normalraggedright{\let\\=\@centercr\leftskip\z@
                       \@rightskip\@flushglue\rightskip\@rightskip
                       \parindent\z@}%
\def\letterraggedright{\let\\=\@centercr\leftskip\lettermargin
                       \@rightskip\@flushglue\rightskip\@rightskip
                       \parindent\z@}%
\let\endflushleft=\endtrivlist
%
%    ****************************************
%    *               LISTES                 *
%    ****************************************
%
\def\reset@frenchitemize{%
      \renewenvironment{itemize}%
        {\begin{list}{\textendash}%
          {\settowidth{\labelwidth}{\textendash}%
           \setlength{\leftmargin}{\listmargin}%
           \addtolength{\leftmargin}{\labelwidth}%
           \addtolength{\leftmargin}{\labelsep}%
           \ifnum\@listdepth=0
             \setlength{\itemindent}{\parindent}%
           \else
             \addtolength{\leftmargin}{\parindent}%
           \fi
           \setlength{\itemsep}{\z@}%
           \setlength{\parsep}{\z@}%
           \setlength{\topsep}{\z@}%
           \setlength{\partopsep}{\z@}%
           \addtolength{\topsep}{-\parskip}%
           \addtolength{\partopsep}{\parskip}%
          }%
        }%
        {\end{list}}%
}
%
\rightmargin   25mm%
   \advance\rightmargin   5pt%
\leftmarginii  2.2em%
\leftmarginiii 1.87em%
\leftmarginiv  1.7em%
\leftmarginv   1em%
\leftmarginvi  1em%
\leftmargin\leftmargini
\labelsep 5pt%
\parsep 0pt%
\def\@listi{\leftmargin\listmargin\labelwidth\leftmargin
   \advance\leftmargin 1.5em\advance\labelwidth-\labelsep}%
\def\@listii{\leftmargin\leftmarginii
   \labelwidth\leftmarginii\advance\labelwidth-\labelsep}%
\def\@listiii{\leftmargin\leftmarginiii
    \labelwidth\leftmarginiii\advance\labelwidth-\labelsep
    \topsep .1em% 
    \itemsep \topsep}%
\def\@listiv{\leftmargin\leftmarginiv
     \labelwidth\leftmarginiv\advance\labelwidth-\labelsep}%
\def\@listv{\leftmargin\leftmarginv
     \labelwidth\leftmarginv\advance\labelwidth-\labelsep}%
\def\@listvi{\leftmargin\leftmarginvi
     \labelwidth\leftmarginvi\advance\labelwidth-\labelsep}%
%
\def\labelitemi{$\bullet$}%
\def\labelitemii{\bfseries --}%
\def\labelitemiii{$\ast$}%
\def\labelitemiv{$\cdot$}%
%
\def\labelenumi{\arabic{enumi}.}%
\def\theenumi{\arabic{enumi}}%     
\def\labelenumii{(\alph{enumii})}%
\def\theenumii{\alph{enumii}}%
\def\p@enumii{\theenumi}%
\def\labelenumiii{\roman{enumiii}.}%
\def\theenumiii{\roman{enumiii}}%
\def\p@enumiii{\theenumi(\theenumii)}%
\def\labelenumiv{\Alph{enumiv}.}%
\def\theenumiv{\Alph{enumiv}}%
\def\p@enumiv{\p@enumiii\theenumiii}%
%
\def\verse{\let\\=\@centercr  
  \list{}{\itemsep\z@ \itemindent -15pt\listparindent \itemindent 
          \rightmargin\leftmargin\advance\leftmargin 15pt}\item[]}%
\let\endverse\endlist
%   
\def\quotation{\list{}{\listparindent 1.5em%
    \itemindent\listparindent
    \rightmargin\leftmargin}\item[]}%
\let\endquotation=\endlist
%
\def\quote{\list{}{\rightmargin\leftmargin}\item[]}%
\let\endquote=\endlist
%
\def\descriptionlabel#1{\itshape #1}%
\def\description{\list{}{\leftmargin=2\listmargin
       \labelwidth\listmargin \advance\labelwidth -\labelsep 
       \let\makelabel\descriptionlabel}}%
\let\enddescription\endlist
%
%    ****************************************
%    *              SECTIONS                *
%    ****************************************
%
\setcounter{secnumdepth}{3}
\newcounter {section}
\newcounter {subsection}[section]
\newcounter {subsubsection}[subsection]
\newcounter {paragraph}[subsubsection]
\newcounter {subparagraph}[paragraph]
\renewcommand\thesection {\@arabic\c@section}
\renewcommand\thesubsection   {\thesection.\@arabic\c@subsection}
\renewcommand\thesubsubsection{\thesubsection.\@arabic\c@subsubsection}
\renewcommand\theparagraph    {\thesubsubsection.\@arabic\c@paragraph}
\renewcommand\thesubparagraph {\theparagraph.\@arabic\c@subparagraph}

\newcommand\section{\@startsection {section}{1}{\z@}%
                                   {-3.5ex \@plus -1ex \@minus -.2ex}%
                                   {2.3ex \@plus.2ex}%
                                   {\normalfont\Large\bfseries}}
\newcommand\subsection{\@startsection{subsection}{2}{\z@}%
                                     {-3.25ex\@plus -1ex \@minus -.2ex}%
                                     {1.5ex \@plus .2ex}%
                                     {\normalfont\large\bfseries}}
\newcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
                                     {-3.25ex\@plus -1ex \@minus -.2ex}%
                                     {1.5ex \@plus .2ex}%
                                     {\normalfont\normalsize\bfseries}}
\newcommand\paragraph{\@startsection{paragraph}{4}{\z@}%
                                    {3.25ex \@plus1ex \@minus.2ex}%
                                    {-1em}%
                                    {\normalfont\normalsize\itshape}}
\newcommand\subparagraph{\@startsection{subparagraph}{5}{\parindent}%
                                       {3.25ex \@plus1ex \@minus .2ex}%
                                       {-1em}%
                                      {\normalfont\normalsize\itshape}}
\newcommand\appendix{\par
  \setcounter{section}{0}%
  \setcounter{subsection}{0}%
  \gdef\thesection{\@Alph\c@section}}


%
%    ****************************************
%    *               DIVERS                 *
%    ****************************************
%
\def\@begintheorem#1#2{\itshape \trivlist \item[\hskip \labelsep{\bfseries #1\ #2}]}%
\def\@endtheorem{\endtrivlist}%
%
\def\theequation{\arabic{equation}}%
%
\arraycolsep 5pt%
\tabcolsep 5pt%
\arrayrulewidth .4pt%
\doublerulesep 2pt%
\tabbingsep\labelsep
\skip\@mpfootins=\skip\footins
%
\fboxsep = 3pt    % Space left between box and text by \fbox and \framebox.
\fboxrule = .4pt  % Width of rules in box made by \fbox and \framebox.
%
%    ****************************************
%    *             FOOTNOTES                *
%    ****************************************
%
\def\footnoterule{\kern-1\p@   
  \hrule width .4\columnwidth 
  \kern .6\p@}%
%
\long\def\@makefntext#1{\parindent 1em\noindent
            \hb@xt@1.8em{%
                \hss\@textsuperscript{\normalfont\@thefnmark}}#1}%
%
%    ****************************************
%    *     INITIALISATIONS DES DEFAUTS      *
%    ****************************************
%
\def\pict@let@width{185}%
\def\pict@let@height{65}%
\def\pict@let@hoffset{0}%
\def\pict@let@voffset{0}%
\def\rule@hpos{-35}%
\def\rule@vpos{0}%
\def\rule@length{10}%
\def\rule@width{.1}%
\def\nopliure{\def\rule@width{0}}%
\def\pliure{\def\rule@width{.2}}%
\def\fromaddress@let@hpos{-10}%
\def\fromaddress@let@vpos{70}%
\fromaddress@let@width=69mm
\def\fromlieu@let@hpos{90}%
\def\fromlieu@let@vpos{62}%
\fromlieu@let@width=69mm
\def\toaddress@let@hpos{90}%
\def\toaddress@let@vpos{40}%
\toaddress@let@width=80mm
%
\def\pict@fax@width{185}%
\def\pict@fax@height{30}%
\def\pict@fax@hoffset{0}%
\def\pict@fax@voffset{0}%
\def\fromaddress@fax@hpos{-10}%
\def\fromaddress@fax@vpos{30}%
\fromaddress@fax@width=69mm
\def\faxstring@hpos{80}%
\def\faxstring@vpos{20}%
\faxstring@width=69mm%
\faxbox@width=170mm%
\toaddress@fax@width=69mm%
\fromname@fax@width=69mm%
%
%\def\@institut{\makeatletter
%         \input{defaultLSV.ins}%
%         \makeatother}%
%
\smallskipamount=.5\parskip
\medskipamount=\parskip
\bigskipamount=2\parskip
%
\ps@plain
\pagenumbering{arabic}%
\raggedbottom
\onecolumn
%
% Initialisations des variables de la lettre
%
\def\pdate{\cejour}%
%
\def\emailnum{}%
\def\secondemailnum{}%
%
\def\fromlocation{}%
\signum=0\relax
\def\fromsig{}%
\def\fromssig{}%
\def\fromtsig{}%
\def\fromsigfile{}%
\def\fromssigfile{}%
\def\fromtsigfile{}%
%
\csname\defaultlanguage\endcsname
\l@@info{Langage par defaut: \defaultlanguage}
\def\concdecl{}%
%
\marge{-10mm}%
\msigwidth=\letterwidth
\ssigindent=0.5\letterwidth
\ssigwidth=\letterwidth
  \advance\ssigwidth by -\ssigindent
  \advance\ssigwidth by -5pt
\sigspace=0cm
\openingspace=3mm
\openingindent=0em
%
\@lettertrue        
\faxpage=0\relax
\def\totalpages{}%
%
\def\auxflag{}%
\auxcount=0\relax
\def\toref{}%
\def\fromref{}%
\def\telexnum{}%
\def\ccpnum{}%
%
\def\emailflag{}%
\emailcount=0\relax
\def\@username{}%
\def\ccittnum{}%
\def\internetnum{}%
\def\bitnetnum{}%
\def\telepacnum{}%
\def\decnetnum{}%
%
\def\bdp{}%

\expandafter\ifx\csname @insfile\endcsname\relax
  \input{empty.ins}
\else
  \input{\@insfile}
\fi

\endinput
%%
%% End of file `lettre.cls'.
